==> spring-hateoas-2.0.5-sources.jar: org/springframework/hateoas/aot/HateoasTypesRuntimeHints.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.hateoas.aot;

import org.springframework.aot.hint.MemberCategory;
import org.springframework.aot.hint.RuntimeHints;
import org.springframework.aot.hint.RuntimeHintsRegistrar;
import org.springframework.hateoas.RepresentationModel;

/**
 * Registers reflection metadata for {@link RepresentationModel} types.
 *
 * @author Oliver Drotbohm
 */
class HateoasTypesRuntimeHints implements RuntimeHintsRegistrar {

	/*
	 * (non-Javadoc)
	 * @see org.springframework.aot.hint.RuntimeHintsRegistrar#registerHints(org.springframework.aot.hint.RuntimeHints, java.lang.ClassLoader)
	 */
	@Override
	public void registerHints(RuntimeHints hints, ClassLoader classLoader) {

		var reflection = hints.reflection();

		AotUtils.getScanner(RepresentationModel.class.getPackageName()) //
				.findClasses() //
				.forEach(it -> reflection.registerType(it, //
						MemberCategory.INVOKE_DECLARED_CONSTRUCTORS, //
						MemberCategory.INVOKE_DECLARED_METHODS));
	}
}

==> spring-hateoas-3.0.1-sources.jar: org/springframework/hateoas/aot/HateoasTypesRuntimeHints.java <==
/*
 * Copyright 2022-2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.hateoas.aot;

import java.util.Map;

import org.jspecify.annotations.Nullable;
import org.springframework.aop.SpringProxy;
import org.springframework.aop.framework.Advised;
import org.springframework.aot.hint.RuntimeHints;
import org.springframework.aot.hint.RuntimeHintsRegistrar;
import org.springframework.core.DecoratingProxy;
import org.springframework.hateoas.RepresentationModel;
import org.springframework.hateoas.server.core.LastInvocationAware;

/**
 * Registers reflection metadata for {@link RepresentationModel} types.
 *
 * @author Oliver Drotbohm
 */
class HateoasTypesRuntimeHints implements RuntimeHintsRegistrar {

	/*
	 * (non-Javadoc)
	 * @see org.springframework.aot.hint.RuntimeHintsRegistrar#registerHints(org.springframework.aot.hint.RuntimeHints, java.lang.ClassLoader)
	 */
	@Override
	public void registerHints(RuntimeHints hints, @Nullable ClassLoader classLoader) {

		var packageName = RepresentationModel.class.getPackageName();
		var reflection = hints.reflection();

		AotUtils.registerTypesForReflection(packageName, reflection);

		// Proxy metadata for DummyInvocationUtils
		hints.proxies()
				.registerJdkProxy(LastInvocationAware.class, Map.class, SpringProxy.class, Advised.class,
						DecoratingProxy.class);
	}
}
